Class: Google::Apis::ContactcenteraiplatformV1alpha1::GenerateShiftsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb

Overview

Request with constraints for generating shifts. The shifts generated must adhere to these constraints.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateShiftsRequest

Returns a new instance of GenerateShiftsRequest.



626
627
628
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#employee_infoArray<Google::Apis::ContactcenteraiplatformV1alpha1::EmployeeInfo>

Optional. Employee information that should be considered when generating shifts. Corresponds to the JSON property employeeInfo



602
603
604
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 602

def employee_info
  @employee_info
end

#planning_horizonGoogle::Apis::ContactcenteraiplatformV1alpha1::PlanningHorizon

Specifies the time interval during which the solver should generate shifts. The start time must be before the end time. Corresponds to the JSON property planningHorizon



608
609
610
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 608

def planning_horizon
  @planning_horizon
end

#shift_templatesArray<Google::Apis::ContactcenteraiplatformV1alpha1::ShiftTemplate>

Required. Set of shift templates specifying rules for generating shifts. A shift template can be used for generating multiple shifts. Corresponds to the JSON property shiftTemplates



614
615
616
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 614

def shift_templates
  @shift_templates
end

#solver_configGoogle::Apis::ContactcenteraiplatformV1alpha1::SolverConfig

Specifies additional parameters for the solver generating shifts. Corresponds to the JSON property solverConfig



619
620
621
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 619

def solver_config
  @solver_config
end

#workforce_demandsGoogle::Apis::ContactcenteraiplatformV1alpha1::WorkforceDemandList

List of workforce demands. Corresponds to the JSON property workforceDemands



624
625
626
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 624

def workforce_demands
  @workforce_demands
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



631
632
633
634
635
636
637
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 631

def update!(**args)
  @employee_info = args[:employee_info] if args.key?(:employee_info)
  @planning_horizon = args[:planning_horizon] if args.key?(:planning_horizon)
  @shift_templates = args[:shift_templates] if args.key?(:shift_templates)
  @solver_config = args[:solver_config] if args.key?(:solver_config)
  @workforce_demands = args[:workforce_demands] if args.key?(:workforce_demands)
end