Class: Google::Apis::ContactcenteraiplatformV1alpha1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



979
980
981
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 938

def api_version
  @api_version
end

#contact_centerGoogle::Apis::ContactcenteraiplatformV1alpha1::ContactCenter

Message describing ContactCenter object Corresponds to the JSON property contactCenter



943
944
945
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 943

def contact_center
  @contact_center
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


948
949
950
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 948

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


953
954
955
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 953

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


961
962
963
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 961

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


967
968
969
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 967

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


972
973
974
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 972

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


977
978
979
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 977

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



984
985
986
987
988
989
990
991
992
993
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 984

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @contact_center = args[:contact_center] if args.key?(:contact_center)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end