Class: Google::Apis::ContactcenteraiplatformV1alpha1::SolverConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb

Overview

Specifies additional parameters for the solver generating shifts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SolverConfig

Returns a new instance of SolverConfig.



1319
1320
1321
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maximum_processing_durationString

Optional. Maximum time the solver should spend on the problem. If not set, defaults to 1 minute. The choice of a time limit should depend on the size of the problem. To give an example, when solving a 7-day instance with 2 ShiftTemplates, each with ~20 possible start times and holding 2 events with ~ 30 possible start times, and two days off per week, recommended values are: < 10s for fast solutions (and likely suboptimal), (10s, 300s) for good quality solutions, and >300s for an exhaustive search. Larger instances may require longer time limits. This value is not a hard limit and it does not account for the communication overhead. The expected latency to solve the problem may slightly exceed this value. Corresponds to the JSON property maximumProcessingDuration

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1312

def maximum_processing_duration
  @maximum_processing_duration
end

#schedule_typeString

Required. Specifies the type of schedule to generate. Corresponds to the JSON property scheduleType

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1317

def schedule_type
  @schedule_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1324
1325
1326
1327
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1324

def update!(**args)
  @maximum_processing_duration = args[:maximum_processing_duration] if args.key?(:maximum_processing_duration)
  @schedule_type = args[:schedule_type] if args.key?(:schedule_type)
end