Class: Google::Apis::ContactcenteraiplatformV1alpha1::UnwantedEventInterval

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb

Overview

Specifies a time interval during which the overlap with events (generated from event templates) should be minimal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnwantedEventInterval

Returns a new instance of UnwantedEventInterval.



1505
1506
1507
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duration_minutesFixnum

Required. Duration of the event. Corresponds to the JSON property durationMinutes

Returns:

  • (Fixnum)


1485
1486
1487
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1485

def duration_minutes
  @duration_minutes
end

#start_timeGoogle::Apis::ContactcenteraiplatformV1alpha1::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property startTime



1503
1504
1505
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1503

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1510
1511
1512
1513
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1510

def update!(**args)
  @duration_minutes = args[:duration_minutes] if args.key?(:duration_minutes)
  @start_time = args[:start_time] if args.key?(:start_time)
end