Class: Google::Apis::ContactcenteraiplatformV1alpha1::WeeklySchedule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb

Overview

Message representing a weekly schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeeklySchedule

Returns a new instance of WeeklySchedule.



1544
1545
1546
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#daysArray<String>

Required. Days of the week this schedule applies to. Corresponds to the JSON property days

Returns:

  • (Array<String>)


1523
1524
1525
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1523

def days
  @days
end

#durationString

Optional. Duration of the schedule. Corresponds to the JSON property duration

Returns:

  • (String)


1528
1529
1530
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1528

def duration
  @duration
end

#end_timeGoogle::Apis::ContactcenteraiplatformV1alpha1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property endTime



1535
1536
1537
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1535

def end_time
  @end_time
end

#start_timeGoogle::Apis::ContactcenteraiplatformV1alpha1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



1542
1543
1544
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1542

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1549
1550
1551
1552
1553
1554
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1549

def update!(**args)
  @days = args[:days] if args.key?(:days)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end