Class: Google::Apis::ContactcenteraiplatformV1alpha1::WorkforceDemand

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb

Overview

Specifies the number of employees required to cover the demand in the given time interval. The length of the interval must be strictly positive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkforceDemand

Returns a new instance of WorkforceDemand.



1603
1604
1605
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#employee_countFixnum

Optional. Number of employees needed to cover the demand for this interval. Corresponds to the JSON property employeeCount

Returns:

  • (Fixnum)


1565
1566
1567
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1565

def employee_count
  @employee_count
end

#end_timeGoogle::Apis::ContactcenteraiplatformV1alpha1::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property endTime



1583
1584
1585
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1583

def end_time
  @end_time
end

#start_timeGoogle::Apis::ContactcenteraiplatformV1alpha1::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property startTime



1601
1602
1603
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1601

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1608
1609
1610
1611
1612
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1608

def update!(**args)
  @employee_count = args[:employee_count] if args.key?(:employee_count)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end