Class: Google::Apis::ContactcenteraiplatformV1alpha1::CCAIPlatformService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::ContactcenteraiplatformV1alpha1::CCAIPlatformService
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb
Overview
Contact Center AI Platform API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://contactcenteraiplatform.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_contact_center(parent, contact_center_object = nil, contact_center_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Creates a new ContactCenter in a given project and location.
-
#delete_project_location_contact_center(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Deletes a single ContactCenter.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Empty
Deletes a long-running operation.
-
#generate_location_shifts(parent, generate_shifts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Generates shifts constrained by various parameters.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Location
Gets information about a location.
-
#get_project_location_contact_center(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter
Gets details of a single ContactCenter.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CCAIPlatformService
constructor
A new instance of CCAIPlatformService.
-
#list_project_location_contact_centers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ListContactCentersResponse
Lists ContactCenters in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_contact_center(name, contact_center_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Updates the parameters of a single ContactCenter.
-
#query_project_location_contact_center_quota(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenterQuota
Queries the contact center quota, an aggregation over all the projects, that belongs to the billing account, which the input project belongs to.
Constructor Details
#initialize ⇒ CCAIPlatformService
Returns a new instance of CCAIPlatformService.
47 48 49 50 51 52 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-contactcenteraiplatform_v1alpha1', client_version: Google::Apis::ContactcenteraiplatformV1alpha1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 450 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:cancel', ) command.request_representation = Google::Apis::ContactcenteraiplatformV1alpha1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Empty::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_contact_center(parent, contact_center_object = nil, contact_center_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Creates a new ContactCenter in a given project and location.
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 241 def create_project_location_contact_center(parent, contact_center_object = nil, contact_center_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/contactCenters', ) command.request_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter::Representation command.request_object = contact_center_object command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Operation::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['contactCenterId'] = contact_center_id unless contact_center_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_contact_center(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Deletes a single ContactCenter.
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 286 def delete_project_location_contact_center(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Operation::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
485 486 487 488 489 490 491 492 493 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 485 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Empty::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_location_shifts(parent, generate_shifts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Generates shifts constrained by various parameters.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 76 def generate_location_shifts(parent, generate_shifts_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}:generateShifts', ) command.request_representation = Google::Apis::ContactcenteraiplatformV1alpha1::GenerateShiftsRequest::Representation command.request_object = generate_shifts_request_object command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Operation::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Location
Gets information about a location.
108 109 110 111 112 113 114 115 116 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 108 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Location::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_contact_center(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter
Gets details of a single ContactCenter.
317 318 319 320 321 322 323 324 325 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 317 def get_project_location_contact_center(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
516 517 518 519 520 521 522 523 524 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 516 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Operation::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_contact_centers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ListContactCentersResponse
Lists ContactCenters in a given project and location.
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 356 def list_project_location_contact_centers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/contactCenters', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ListContactCentersResponse::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::ListContactCentersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 561 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/operations', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ListOperationsResponse::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 160 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/locations', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ListLocationsResponse::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_contact_center(name, contact_center_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Operation
Updates the parameters of a single ContactCenter.
408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 408 def patch_project_location_contact_center(name, contact_center_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter::Representation command.request_object = contact_center_object command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::Operation::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_project_location_contact_center_quota(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenterQuota
Queries the contact center quota, an aggregation over all the projects, that belongs to the billing account, which the input project belongs to.
195 196 197 198 199 200 201 202 203 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/service.rb', line 195 def query_project_location_contact_center_quota(parent, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}:queryContactCenterQuota', ) command.response_representation = Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenterQuota::Representation command.response_class = Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenterQuota command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |