Class: Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenteraiplatformV1alpha1::ContactCenter
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb
Overview
Message describing ContactCenter object
Instance Attribute Summary collapse
-
#admin_user ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::AdminUser
Message storing info about the first admin user.
-
#advanced_reporting_enabled ⇒ Boolean
(also: #advanced_reporting_enabled?)
Optional.
-
#ccaip_managed_users ⇒ Boolean
(also: #ccaip_managed_users?)
Optional.
-
#create_time ⇒ String
Output only.
-
#critical ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Critical
Instances in this Channel will receive updates after all instances in
Normalwere updated. -
#customer_domain_prefix ⇒ String
Required.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#early ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Early
LINT.IfChange First Channel to receive the updates.
-
#expire_time ⇒ String
Output only.
-
#feature_config ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::FeatureConfig
Optional.
-
#instance_config ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::InstanceConfig
Message storing the instance configuration.
-
#kms_key ⇒ String
Immutable.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs Corresponds to the JSON property
labels. -
#name ⇒ String
name of resource Corresponds to the JSON property
name. -
#normal ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Normal
Instances in this Channel will receive updates after all instances in
Earlywere updated + 2 days. -
#private_access ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::PrivateAccess
Defines ingress and egress private traffic settings for CCAIP instances.
-
#private_components ⇒ Array<String>
Output only.
-
#purge_time ⇒ String
Output only.
-
#release_version ⇒ String
Output only.
-
#saml_params ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::SamlParams
Message storing SAML params to enable Google as IDP.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#uris ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::UrIs
Message storing the URIs of the ContactCenter.
-
#user_email ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContactCenter
constructor
A new instance of ContactCenter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContactCenter
Returns a new instance of ContactCenter.
230 231 232 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_user ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::AdminUser
Message storing info about the first admin user. Next ID: 3
Corresponds to the JSON property adminUser
100 101 102 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 100 def admin_user @admin_user end |
#advanced_reporting_enabled ⇒ Boolean Also known as: advanced_reporting_enabled?
Optional. Whether the advanced reporting feature is enabled.
Corresponds to the JSON property advancedReportingEnabled
105 106 107 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 105 def advanced_reporting_enabled @advanced_reporting_enabled end |
#ccaip_managed_users ⇒ Boolean Also known as: ccaip_managed_users?
Optional. Whether to enable users to be created in the CCAIP-instance
concurrently to having users in Cloud identity
Corresponds to the JSON property ccaipManagedUsers
112 113 114 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 112 def ccaip_managed_users @ccaip_managed_users end |
#create_time ⇒ String
Output only. [Output only] Create time stamp
Corresponds to the JSON property createTime
118 119 120 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 118 def create_time @create_time end |
#critical ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Critical
Instances in this Channel will receive updates after all instances in Normal
were updated. They also will only be updated outside of their peak hours.
Corresponds to the JSON property critical
124 125 126 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 124 def critical @critical end |
#customer_domain_prefix ⇒ String
Required. Immutable. At least 2 and max 16 char long, must conform to RFC
1035.
Corresponds to the JSON property customerDomainPrefix
130 131 132 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 130 def customer_domain_prefix @customer_domain_prefix end |
#delete_time ⇒ String
Output only. Timestamp in UTC of when this resource was soft-deleted.
Corresponds to the JSON property deleteTime
135 136 137 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 135 def delete_time @delete_time end |
#display_name ⇒ String
Required. A user friendly name for the ContactCenter.
Corresponds to the JSON property displayName
140 141 142 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 140 def display_name @display_name end |
#early ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Early
LINT.IfChange First Channel to receive the updates. Meant to dev/test
instances
Corresponds to the JSON property early
146 147 148 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 146 def early @early end |
#expire_time ⇒ String
Output only. Timestamp in UTC of when this resource is considered expired.
Corresponds to the JSON property expireTime
151 152 153 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 151 def expire_time @expire_time end |
#feature_config ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::FeatureConfig
Optional. Feature configuration to populate the feature flags.
Corresponds to the JSON property featureConfig
156 157 158 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 156 def feature_config @feature_config end |
#instance_config ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::InstanceConfig
Message storing the instance configuration.
Corresponds to the JSON property instanceConfig
161 162 163 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 161 def instance_config @instance_config end |
#kms_key ⇒ String
Immutable. The KMS key name to encrypt the user input (ContactCenter).
Corresponds to the JSON property kmsKey
166 167 168 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 166 def kms_key @kms_key end |
#labels ⇒ Hash<String,String>
Labels as key value pairs
Corresponds to the JSON property labels
171 172 173 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 171 def labels @labels end |
#name ⇒ String
name of resource
Corresponds to the JSON property name
176 177 178 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 176 def name @name end |
#normal ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::Normal
Instances in this Channel will receive updates after all instances in Early
were updated + 2 days.
Corresponds to the JSON property normal
182 183 184 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 182 def normal @normal end |
#private_access ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::PrivateAccess
Defines ingress and egress private traffic settings for CCAIP instances.
Corresponds to the JSON property privateAccess
187 188 189 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 187 def private_access @private_access end |
#private_components ⇒ Array<String>
Output only. TODO(b/283407860) Deprecate this field.
Corresponds to the JSON property privateComponents
192 193 194 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 192 def private_components @private_components end |
#purge_time ⇒ String
Output only. Timestamp in UTC of when this resource is going to be hard-
deleted.
Corresponds to the JSON property purgeTime
198 199 200 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 198 def purge_time @purge_time end |
#release_version ⇒ String
Output only. UJET release version, unique for each new release.
Corresponds to the JSON property releaseVersion
203 204 205 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 203 def release_version @release_version end |
#saml_params ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::SamlParams
Message storing SAML params to enable Google as IDP.
Corresponds to the JSON property samlParams
208 209 210 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 208 def saml_params @saml_params end |
#state ⇒ String
Output only. The state of this contact center.
Corresponds to the JSON property state
213 214 215 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 213 def state @state end |
#update_time ⇒ String
Output only. [Output only] Update time stamp
Corresponds to the JSON property updateTime
218 219 220 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 218 def update_time @update_time end |
#uris ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::UrIs
Message storing the URIs of the ContactCenter.
Corresponds to the JSON property uris
223 224 225 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 223 def uris @uris end |
#user_email ⇒ String
Optional. Email address of the first admin user.
Corresponds to the JSON property userEmail
228 229 230 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 228 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 235 def update!(**args) @admin_user = args[:admin_user] if args.key?(:admin_user) @advanced_reporting_enabled = args[:advanced_reporting_enabled] if args.key?(:advanced_reporting_enabled) @ccaip_managed_users = args[:ccaip_managed_users] if args.key?(:ccaip_managed_users) @create_time = args[:create_time] if args.key?(:create_time) @critical = args[:critical] if args.key?(:critical) @customer_domain_prefix = args[:customer_domain_prefix] if args.key?(:customer_domain_prefix) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @early = args[:early] if args.key?(:early) @expire_time = args[:expire_time] if args.key?(:expire_time) @feature_config = args[:feature_config] if args.key?(:feature_config) @instance_config = args[:instance_config] if args.key?(:instance_config) @kms_key = args[:kms_key] if args.key?(:kms_key) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @normal = args[:normal] if args.key?(:normal) @private_access = args[:private_access] if args.key?(:private_access) @private_components = args[:private_components] if args.key?(:private_components) @purge_time = args[:purge_time] if args.key?(:purge_time) @release_version = args[:release_version] if args.key?(:release_version) @saml_params = args[:saml_params] if args.key?(:saml_params) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @uris = args[:uris] if args.key?(:uris) @user_email = args[:user_email] if args.key?(:user_email) end |