Class: Google::Apis::ContactcenteraiplatformV1alpha1::Critical
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenteraiplatformV1alpha1::Critical
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb
Overview
Instances in this Channel will receive updates after all instances in Normal
were updated. They also will only be updated outside of their peak hours.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ Critical
constructor
A new instance of Critical.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Critical
Returns a new instance of Critical.
307 308 309 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peak_hours ⇒ Array<Google::Apis::ContactcenteraiplatformV1alpha1::WeeklySchedule>
Required. Hours during which the instance should not be updated.
Corresponds to the JSON property peakHours
305 306 307 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 305 def peak_hours @peak_hours end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
312 313 314 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 312 def update!(**args) @peak_hours = args[:peak_hours] if args.key?(:peak_hours) end |