Class: Google::Apis::ContactcenteraiplatformV1alpha1::EmployeeInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenteraiplatformV1alpha1::EmployeeInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb
Overview
Information about a particular employee for planning purposes.
Instance Attribute Summary collapse
-
#id ⇒ String
Required.
-
#unwanted_event_intervals ⇒ Array<Google::Apis::ContactcenteraiplatformV1alpha1::UnwantedEventInterval>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmployeeInfo
constructor
A new instance of EmployeeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmployeeInfo
Returns a new instance of EmployeeInfo.
495 496 497 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Required. Unique ID of this employee.
Corresponds to the JSON property id
487 488 489 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 487 def id @id end |
#unwanted_event_intervals ⇒ Array<Google::Apis::ContactcenteraiplatformV1alpha1::UnwantedEventInterval>
Optional. A list of unwanted event intervals for this employee. The start time
of the interval must be in the planning horizon.
Corresponds to the JSON property unwantedEventIntervals
493 494 495 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 493 def unwanted_event_intervals @unwanted_event_intervals end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
500 501 502 503 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 500 def update!(**args) @id = args[:id] if args.key?(:id) @unwanted_event_intervals = args[:unwanted_event_intervals] if args.key?(:unwanted_event_intervals) end |