Class: Google::Apis::ContactcenteraiplatformV1alpha1::PlanningHorizon
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenteraiplatformV1alpha1::PlanningHorizon
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb
Overview
Specifies the time interval during which the solver should generate shifts. The start time must be before the end time.
Instance Attribute Summary collapse
-
#end_time ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::DateTime
Represents civil time (or occasionally physical time).
-
#start_time ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::DateTime
Represents civil time (or occasionally physical time).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlanningHorizon
constructor
A new instance of PlanningHorizon.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlanningHorizon
Returns a new instance of PlanningHorizon.
1037 1038 1039 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::DateTime
Represents civil time (or occasionally physical time). This type can represent
a civil time in one of a few possible ways: * When utc_offset is set and
time_zone is unset: a civil time on a calendar day with a particular offset
from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
calendar day in a particular time zone. * When neither time_zone nor
utc_offset is set: a civil time on a calendar day in local time. The date is
relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
the DateTime is considered not to have a specific year, month, or day
respectively. This type may also be used to represent a physical time if all
the date and time fields are set and either case of the time_offset oneof is
set. Consider using Timestamp message for physical time instead. If your use
case also would like to store the user's timezone, that can be done in another
field. This type is more flexible than some applications may want. Make sure
to document and validate your application's limitations.
Corresponds to the JSON property endTime
1017 1018 1019 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1017 def end_time @end_time end |
#start_time ⇒ Google::Apis::ContactcenteraiplatformV1alpha1::DateTime
Represents civil time (or occasionally physical time). This type can represent
a civil time in one of a few possible ways: * When utc_offset is set and
time_zone is unset: a civil time on a calendar day with a particular offset
from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
calendar day in a particular time zone. * When neither time_zone nor
utc_offset is set: a civil time on a calendar day in local time. The date is
relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
the DateTime is considered not to have a specific year, month, or day
respectively. This type may also be used to represent a physical time if all
the date and time fields are set and either case of the time_offset oneof is
set. Consider using Timestamp message for physical time instead. If your use
case also would like to store the user's timezone, that can be done in another
field. This type is more flexible than some applications may want. Make sure
to document and validate your application's limitations.
Corresponds to the JSON property startTime
1035 1036 1037 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1035 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1042 1043 1044 1045 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1042 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |