Class: Google::Apis::ContactcenteraiplatformV1alpha1::PscSetting
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenteraiplatformV1alpha1::PscSetting
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb
Overview
Private service connect settings.
Instance Attribute Summary collapse
-
#allowed_consumer_project_ids ⇒ Array<String>
The list of project ids that are allowed to send traffic to the service attachment.
-
#producer_project_ids ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscSetting
constructor
A new instance of PscSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscSetting
Returns a new instance of PscSetting.
1096 1097 1098 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_consumer_project_ids ⇒ Array<String>
The list of project ids that are allowed to send traffic to the service
attachment. This field should be filled only for the ingress components.
Corresponds to the JSON property allowedConsumerProjectIds
1089 1090 1091 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1089 def allowed_consumer_project_ids @allowed_consumer_project_ids end |
#producer_project_ids ⇒ Array<String>
Output only. The CCAIP tenant project ids.
Corresponds to the JSON property producerProjectIds
1094 1095 1096 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1094 def producer_project_ids @producer_project_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1101 1102 1103 1104 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1101 def update!(**args) @allowed_consumer_project_ids = args[:allowed_consumer_project_ids] if args.key?(:allowed_consumer_project_ids) @producer_project_ids = args[:producer_project_ids] if args.key?(:producer_project_ids) end |