Class: Google::Apis::ContactcenteraiplatformV1alpha1::TimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::ContactcenteraiplatformV1alpha1::TimeOfDay
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb,
lib/google/apis/contactcenteraiplatform_v1alpha1/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeOfDay
constructor
A new instance of TimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeOfDay
Returns a new instance of TimeOfDay.
1401 1402 1403 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
1380 1381 1382 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1380 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
1386 1387 1388 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1386 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
1392 1393 1394 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1392 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
1399 1400 1401 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1399 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1406 1407 1408 1409 1410 1411 |
# File 'lib/google/apis/contactcenteraiplatform_v1alpha1/classes.rb', line 1406 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |